@@ -16,7 +16,7 @@
 ***********************************************************************/
 
 static char const RCSID[] =
-"$Id: mimedefang.c,v 1.224 2005/02/08 17:56:31 dfs Exp $";
+"$Id: mimedefang.c,v 1.226 2005/06/13 15:22:41 dfs Exp $";
 
 /* Define this to work around an M$ Outlook bug! */
 /* #define CONVERT_EMBEDDED_CRS_IN_HEADERS 1 */
@@ -499,32 +499,32 @@ mfconnect(SMFICTX *ctx, char *hostname, _SOCK_ADDR *sa)
 	int n = MXRelayOK(MultiplexorSocketName, buf2, data->hostip,
 			  data->hostname);
 	if (n == 0) {
-	    set_dsn(ctx, buf2, 5);
+	    /* Can't call smfi_setreply from connect callback */
+	    /* set_dsn(ctx, buf2, 5); */
 	    /* We reject connections from this relay */
 	    cleanup(ctx);
 	    DEBUG_EXIT("mfconnect", __LINE__, "SMFIS_REJECT");
 	    return SMFIS_REJECT;
 	}
 	if (n < 0) {
-	    set_dsn(ctx, buf2, 4);
+	    /* Can't call smfi_setreply from connect callback */
+	    /* set_dsn(ctx, buf2, 4); */
 	    cleanup(ctx);
 	    DEBUG_EXIT("mfconnect", __LINE__, "SMFIS_TEMPFAIL");
 	    return SMFIS_TEMPFAIL;
 	}
 	if (n == 2) {
-	    set_dsn(ctx, buf2, 2);
+	    /* Can't call smfi_setreply from connect callback */
+	    /* set_dsn(ctx, buf2, 2); */
 	    cleanup(ctx);
 	    return SMFIS_ACCEPT;
 	}
 	if (n == 3) {
-	    set_dsn(ctx, buf2, 2);
+	    /* Can't call smfi_setreply from connect callback */
+	    /* set_dsn(ctx, buf2, 2); */
 	    cleanup(ctx);
 	    return SMFIS_DISCARD;
 	}
-	if (n == 1) {
-	    /* Called only in case we need to delay */
-	    set_dsn(ctx, buf2, 2);
-	}
     }
 
     DEBUG_EXIT("mfconnect", __LINE__, "SMFIS_CONTINUE");
@@ -702,6 +702,13 @@ envfrom(SMFICTX *ctx, char **from)
 	return SMFIS_TEMPFAIL;
     }
 
+    /* Create the HEADERS file.  Even if we get a wacky e-mail without
+     * any headers, we want an empty HEADERS file lying around */
+    data->headerFD = get_fd(data, "HEADERS", data->headerFD);
+    if (data->headerFD >= 0) {
+	data->headerFD = put_fd(data->headerFD);
+    }
+
     /* Open command file */
     data->cmdFD = get_fd(data, "COMMANDS", data->cmdFD);
     if (data->cmdFD < 0) {
