@@ -4,11 +4,11 @@
 *
 * External declarations and defines.
 *
-* Copyright (C) 2002-2003 by Roaring Penguin Software Inc.
+* Copyright (C) 2002-2005 by Roaring Penguin Software Inc.
 *
 ***********************************************************************/
 
-/* $Id: mimedefang.h,v 1.26 2004/10/29 13:33:25 dfs Exp $ */
+/* $Id: mimedefang.h,v 1.29 2005/02/08 16:04:39 dfs Exp $ */
 
 #ifndef MIMEDEFANG_H
 #define MIMEDEFANG_H 1
@@ -20,7 +20,6 @@
 extern void chomp(char *str);
 extern void write_percent_encoded(unsigned char const *str, int fd);
 extern int percent_encode(unsigned char *in, unsigned char *out, int outlen);
-extern int percent_encode_command(char *out, int outlen, ...);
 extern void percent_decode(unsigned char *buf);
 
 extern int MXCheckFreeSlaves(char const *sockname);
@@ -29,9 +28,10 @@ extern int MXCommand(char const *sockname, char const *cmd, char *buf, int len);
 extern int MXRelayOK(char const *sockname, char *msg,
 		     char const *ip, char const *name);
 extern int MXSenderOK(char const *sockname, char *msg,
-		      char const *sender, char const *ip, char const *name,
+		      char const **sender_argv, char const *ip, char const *name,
 		      char const *helo, char const *dir, char const *qid);
-extern int MXRecipientOK(char const *sockname, char *msg, char const *recip,
+extern int MXRecipientOK(char const *sockname, char *msg,
+			 char const **recip_argv,
 			 char const *sender, char const *ip, char const *name,
 			 char const *firstRecip, char const *helo,
 			 char const *dir, char const *qid,
@@ -55,7 +55,7 @@ extern int writestr(int fd, unsigned char const *buf);
 extern int closefd(int fd);
 extern int validate_smtp_code(char const *code, char const *first);
 extern int validate_smtp_dsn(char const *dsn, char const *first);
-extern int make_listening_socket(char const *str, int backlog);
+extern int make_listening_socket(char const *str, int backlog, int must_be_unix);
 extern int connect_to_socket(char const *str);
 extern void do_delay(char const *sleepstr);
 
